"use strict";

require("core-js/modules/es.promise.js");

require("core-js/modules/es.string.replace.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRoot = createRoot;

function _path() {
  const data = require("@teambit/path.to-windows-compatible-path");

  _path = function () {
    return data;
  };

  return data;
}

function _lodash() {
  const data = require("lodash");

  _lodash = function () {
    return data;
  };

  return data;
}

function _path2() {
  const data = require("path");

  _path2 = function () {
    return data;
  };

  return data;
}

function _ui() {
  const data = require("./ui.aspect");

  _ui = function () {
    return data;
  };

  return data;
}

async function createRoot(aspectDefs, rootExtensionName, rootAspect = _ui().UIAspect.id, runtime = 'ui', config = {}) {
  const rootId = rootExtensionName ? `'${rootExtensionName}'` : '';
  const identifiers = getIdentifiers(aspectDefs, 'Aspect');
  const idSetters = getIdSetters(aspectDefs, 'Aspect');
  return `
${createImports(aspectDefs)}

const isBrowser = typeof window !== "undefined";
const config = JSON.parse('${(0, _path().toWindowsCompatiblePath)(JSON.stringify(config))}');
${idSetters.join('\n')}

export function render(...props){
  return Harmony.load([${identifiers.join(', ')}], '${runtime}', config)
    .then((harmony) => {
      return harmony
      .run()
      .then(() => {
        const rootExtension = harmony.get('${rootAspect}');

        if (isBrowser) {
          return rootExtension.render(${rootId}, ...props);
        } else {
          return rootExtension.renderSsr(${rootId}, ...props);
        }
      })
      .catch((err) => {
        throw err;
      });
    });
}

if (isBrowser) render();
`;
}

function createImports(aspectDefs) {
  const defs = aspectDefs.filter(def => def.runtimePath);
  return `import { Harmony } from '@teambit/harmony';
${getImportStatements(aspectDefs, 'aspectPath', 'Aspect')}
${getImportStatements(defs, 'runtimePath', 'Runtime')}`;
}

function getImportStatements(aspectDefs, pathProp, suffix) {
  return aspectDefs.map(aspectDef => `import ${getIdentifier(aspectDef, suffix)} from '${(0, _path().toWindowsCompatiblePath)(aspectDef[pathProp])}';`).join('\n');
}

function getIdentifiers(aspectDefs, suffix) {
  return aspectDefs.map(aspectDef => `${getIdentifier(aspectDef, suffix)}`);
}

function getIdSetters(defs, suffix) {
  return defs.map(def => {
    if (!def.getId) return undefined;
    return `${getIdentifier(def, suffix)}.id = '${def.getId}';`;
  }).filter(val => !!val);
}

function getIdentifier(aspectDef, suffix) {
  if (!aspectDef.component) {
    return getCoreIdentifier(aspectDef.aspectPath, suffix);
  }

  return getRegularAspectIdentifier(aspectDef, suffix);
}

function getRegularAspectIdentifier(aspectDef, suffix) {
  return (0, _lodash().camelCase)(`${(0, _path2().parse)(aspectDef.aspectPath).base.replace(/\./, '__').replace('@', '__')}${suffix}`);
}

function getCoreIdentifier(path, suffix) {
  return (0, _lodash().camelCase)(`${(0, _path2().parse)(path).name.split('.')[0]}${suffix}`);
}

//# sourceMappingURL=create-root.js.map